@@ -12,6 +12,7 @@ _re_perc = re.compile(r'%')
 _re_excl = re.compile(r'!')
 _re_at = re.compile(r'@')
 _re_qm = re.compile(r'\?')
+_re_cir = re.compile(r'\^')
 
 
 class BaseProvider(object):
@@ -90,6 +91,14 @@ class BaseProvider(object):
         return self.generator.random.choice(
             getattr(string, 'letters', string.ascii_letters))
 
+    def random_lowercase_letter(self):
+        """Returns a random lowercase letter (between a-z)."""
+        return self.generator.random.choice(string.ascii_lowercase)
+
+    def random_uppercase_letter(self):
+        """Returns a random letter (between A-Z)."""
+        return self.generator.random.choice(string.ascii_uppercase)
+
     def random_element(self, elements=('a', 'b', 'c')):
         """
         Returns a random element from a passed object.
@@ -213,3 +222,17 @@ class BaseProvider(object):
         :returns: string with all numerical and letter placeholders filled in
         """
         return self.lexify(self.numerify(text), letters=letters)
+
+    def hexify(self, text='^^^^', upper=False):
+        """
+        Replaces all circumflex ('^') occurrences with a random
+        hexadecimal character.
+
+        :param text: string to be parsed
+        :param upper: Format as uppercase hexadecimal
+        :returns: string with all letter placeholders filled in
+        """
+        letters = string.hexdigits[:-6]
+        if upper:
+            letters = letters.upper()
+        return _re_cir.sub(lambda x: self.random_element(letters), text)
